<template>
    <div class="dialog-table-container">
        <el-row :gutter="12" style="margin-bottom: 20px">
            <el-col :span="4">
                <div class="search-label">项目名称：</div>
                <el-input
                    @change="(val) => search(val, 'PILOT_PROJECT_NAME_')"
                    size="small"
                    v-model="searchData.PILOT_PROJECT_NAME_"
                    clearable
                    suffix-icon="el-icon-search"
                    placeholder="请输入试点项目名称"
                    style="width: 100%"
                ></el-input
            ></el-col>
            <el-col :span="4">
                <div class="search-label">主管部门：</div>
                <el-input
                    @change="(val) => search(val, 'm.UNIT_NAME_')"
                    size="small"
                    v-model="searchData[`m.UNIT_NAME_`]"
                    clearable
                    suffix-icon="el-icon-search"
                    placeholder="请输入主管部门"
                    style="width: 100%"
                ></el-input>
            </el-col>
            <el-col :span="4">
                <div class="search-label">部署时间：</div>
                <el-date-picker
                    @change="(val) => search(val, 'm.START_TIME_')"
                    size="small"
                    v-model="searchData[`m.START_TIME_`]"
                    format="yyyy/MM/dd"
                    value-format="yyyy-MM-dd"
                    type="daterange"
                    range-separator="至"
                    start-placeholder="开始日期"
                    end-placeholder="结束日期"
                    style="width: 100%"
                >
                </el-date-picker>
            </el-col>
            <el-col :span="4">
                <div class="search-label">所属领域：</div>
                <dict-select
                    @select="(val, obj) => search(val, 'PILOT_FIELD_')"
                    class="quarter-selectop"
                    size="small"
                    dictCode="ggbb_ssly"
                    :hasDefaultOption="true"
                    clearable
                    v-model="searchData.PILOT_FIELD_"
                    style="width: 100%"
                    placeholder="请选择所属领域"
                />
            </el-col>
            <el-col :span="4">
                <div class="search-label">所属跑道：</div>
                <el-select
                    @change="(val) => search(val, 'PILOT_RUNWAY_')"
                    class="quarter-selectop"
                    size="small"
                    v-model="searchData.PILOT_RUNWAY_"
                    style="width: 100%"
                    clearable
                    placeholder="请选择所属跑道"
                >
                    <el-option
                        v-for="item in demandRunwayOptions"
                        :key="item.value"
                        :label="item.name"
                        :value="item.value"
                    >
                    </el-option>
                </el-select>
            </el-col>
            <el-col :span="4">
                <div class="search-label">推进状态：</div>
                <dict-select
                    @select="(val, obj) => search(val, 'i.PROPULSIVE_STATUS_')"
                    class="quarter-selectop"
                    size="small"
                    dictCode="tjzt"
                    :hasDefaultOption="true"
                    clearable
                    v-model="searchData[`i.PROPULSIVE_STATUS_`]"
                    style="width: 100%"
                    placeholder="请选择推进状态"
                />
            </el-col>
        </el-row>
        <el-table
            :element-loading-background="loadingColor"
            v-loading="loading"
            height="60vh"
            align="center"
            :data="tableData"
            class="dialog_table"
            :cell-style="{'text-align': 'center'}"
            :header-cell-style="{'text-align': 'center'}"
        >
            <el-table-column
                type="index"
                label="序号"
                width="50"
            ></el-table-column>
            <el-table-column prop="pilotProjectName" label="试点项目名称">
            </el-table-column>
            <el-table-column
                prop="unitName"
                label="主管部门"
                width="160"
            ></el-table-column>
            <el-table-column
                prop="startTime"
                label="部署时间"
                width="100"
            ></el-table-column>
            <el-table-column
                prop="acceptanceTime"
                label="规定验收时间"
                width="100"
            ></el-table-column>
            <el-table-column
                prop="ancPropulsiveStatus"
                label="推进状态"
                width="100"
            >
                <template slot-scope="props">
                    {{ getDictName('tjzt', props.row.ancPropulsiveStatus) }}
                </template>
            </el-table-column>
            <el-table-column prop="status" label="核准状态" width="100">
                <template slot-scope="props">
                    <span v-if="props.row.status == 12">已核准</span>
                    <span v-else>未核准</span>
                </template>
            </el-table-column>
            <el-table-column prop="invs" label="操作" width="100">
                <template v-slot="{row}">
                    <el-tag
                        v-if="row.status == 12"
                        class="qx-tag"
                        effect="dark"
                        @click="handleOpen('districtPilot', row.invs[0], row)"
                        >查看详情</el-tag
                    >
                </template>
            </el-table-column>
        </el-table>
        <pagenation
            class="pagenation"
            @currentChange="pageChange"
            :pageResult="params.pageBean"
        ></pagenation>
        <EasyDialog
            v-model="showEasy"
            :top="dialogOption.top"
            :width="dialogOption.width"
            :title="dialogOption.dialogTitle"
        >
            <component
                v-bind:is="currentTabComponent"
                :tableOptions="tempTableOptions"
            ></component>
        </EasyDialog>
    </div>
</template>

  <script>
import utils from '@/utils.js'
import apiList from '@/api/bigScreen/districView.js'
import EasyDialog from '@/views/BigScreen/components/easy-dialog/index.vue'
import pagenation from './pagenation.vue'
import dialogComponents from '@/views/BigScreen/js/dialog_components.js'
import dialogConfig from '@/views/BigScreen/js/DistrictReformDialogConfig.js'
export default {
    components: {pagenation, ...dialogComponents, EasyDialog},
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            demandRunwayOptions: [],
            loading: false,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            tableData: [],
            showEasy: false,
            currentTabComponent: '',
            dialogOption: {
                dialogTitle: '',
            },
            searchData: {
                PILOT_PROJECT_NAME_: '',
                'i.PROPULSIVE_STATUS_': '',
                'm.UNIT_NAME_': '',
                PILOT_FIELD_: '',
                PILOT_RUNWAY_: '',
                'm.START_TIME_': '',
            },
            tempTableOptions: null,
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 10,
                    showTotal: true,
                    total: 0,
                },
                params: {},
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'PILOT_LEVEL_',
                        relation: 'AND',
                        value: 1,
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'i.UNIT_CODE_',
                        relation: 'AND',
                        value: '',
                    },
                ],
            },
        }
    },
    mounted() {
        this.demandRunwayOptions = this.getDemandData('1')
    },
    watch: {
        'tableOptions.type': {
            handler: function (newValue) {
                this.params.querys[0].value = newValue
                this.params.pageBean.page = 1
                this.params.pageBean.total = 0
                this.params.pageBean.pageSize = 10
                this.loadData()
            },
            immediate: true,
        },
        'tableOptions.code': {
            handler: function (newValue) {
                this.params.querys[1].value = newValue
                this.params.pageBean.page = 1
                this.params.pageBean.total = 0
                this.params.pageBean.pageSize = 10
                this.loadData()
            },
            immediate: true,
        },
    },
    methods: {
        search(data, type) {
            this.params.pageBean.page = 1
            if (type == 'PILOT_FIELD_') {
                this.demandRunwayOptions = this.getDemandData(data)
                this.searchData.PILOT_RUNWAY_ = ''
            }
            let level = this.params.querys[0]
            let unitName = this.params.querys[1]
            this.params.querys = [level, unitName]
            for (let key in this.searchData) {
                let operation = ''
                if (
                    key == 'PILOT_PROJECT_NAME_' ||
                    key == 'i.UNIT_CODE_' ||
                    key == 'm.UNIT_NAME_'
                ) {
                    operation = 'LIKE'
                } else if (
                    key == 'PILOT_FIELD_' ||
                    key == 'PILOT_RUNWAY_' ||
                    key == 'i.PROPULSIVE_STATUS_'
                ) {
                    operation = 'EQUAL'
                } else if (key == 'm.START_TIME_') {
                    operation = 'BETWEEN'
                }
                this.params.querys.push({
                    group: 'main',
                    operation,
                    parentGroup: '',
                    property: key,
                    relation: 'AND',
                    value: this.searchData[key],
                })
            }
            this.loadData()
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        loadData() {
            this.loading = true
            let searchDate = sessionStorage.getItem('searchDate')
            searchDate = JSON.parse(searchDate)
            this.params.params.year = searchDate.year
            this.params.params.quarter = searchDate.quarter
            apiList.pilotLedgerDetailSec(this.params).then((res) => {
                if (res && res.rows) {
                    let tempData = res.rows
                    tempData.forEach((item) => {
                        item.invs = item.invs.filter(
                            (unit) => unit.unitCode == this.tableOptions.code
                        )
                    })
                    this.tableData = tempData
                    this.params.pageBean.page = res.page
                    this.params.pageBean.total = res.total
                    this.params.pageBean.pageSize = res.pageSize
                }
                this.loading = false
            })
        },
        pageChange(key) {
            this.params.pageBean.page = key
            this.loadData()
        },
        handleOpen(type, item, row) {
            console.log(type, item, row)
            this.currentTabComponent = dialogConfig.dialogOption[type]
                .componentName
                ? dialogConfig.dialogOption[type].componentName
                : type // 动态组件名称
            this.tempTableOptions = {
                name: item.unitName,
                code: item.unitCode,
                id: row.id,
            } //table的查询参数
            let data = {
                dialogTitle: item.unitName + '改革试点详情',
                ...dialogConfig.dialogOption[type].option,
            }
            this.dialogOption = data //弹窗配置参数
            this.showEasy = true
        },
        getDemandData(val) {
            if (!val) val = '1'
            let data = null
            let arr = utils.getDictItemsFromCache('ggbb_ssly')
            console.log(arr, 'getDemandData')
            arr.forEach((item) => {
                if (item.value == val) {
                    data = item.lowerDic['ggbb_sspd']
                }
            })
            return data
        },
    },
}
</script>
<style lang="scss" scoped>
/deep/.dialog-table-expand label {
    width: 120px;
    color: #fff;
    font-family: SimHei;
}
/deep/ .qx-tag{
    margin:2px;
    cursor: pointer;
}
/deep/ .el-input__inner {
    background-color: rgba(1, 47, 115, 0.6);
    border: 1px solid #0273E9;
    color: #fff;
}
.search-label{
    color: #fff;
    margin-bottom: 10px;
}
/deep/ .el-date-editor .el-range-input{
    background-color: rgba(1, 47, 115, 0.6);
    color: #fff;
}
/deep/ .el-date-editor .el-range-separator{
    color: #fff;
}
</style>
<style lang="scss">
@import './table.scss';
.el-select-dropdown.el-popper.quarter-selectop{
    background-color: #010b55!important;
    border: solid 1px #0271e5;
}
.quarter-selectop.el-popper[x-placement^="bottom"] .popper__arrow{
    border-bottom-color: #0271e5!important;
}
.quarter-selectop.el-popper[x-placement^="bottom"] .popper__arrow::after{
    display:none;
    border-bottom-color: #0271e5!important;
}
.quarter-selectop {
    .popper__arrow::after{
        border-bottom-color: #0271e5;
    }
    .el-select-dropdown__item.hover, .el-select-dropdown__item:hover {
        background-color: #0271e5;
        color:#fff!important;
    }
    .el-select-dropdown__item.selected span {
        color:#fff!important;
    }
}
</style>
